GET /
^^^^^

Description
    Very basic information about the Instaseis server.

Content-Type
    application/json; charset=UTF-8

Example Response
    .. code-block:: json

        {
            "type": "Instaseis Remote Server"
            "version": "0.0.1a",
        }
